# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Item.pm 66789 2008-07-24T11:49:26.173225Z daisuke  $

package Data::Feed::Item;
use Moose::Role;

no Moose;

1;

__END__

=head1 NAME

Data::Feed::Item - An Item In a Feed

=cut
